==> nextcloud-31.0.6.tar.bz2: nextcloud/apps/files_reminders/l10n/ga.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Meabhrúcháin comhaid",
    "Reminder for {name}" : "Meabhrúchán do {name}",
    "View file" : "Féach ar chomhad",
    "View folder" : "Féach ar fhillteán",
    "Files reminder" : "Meabhrúchán comhaid",
    "The \"files_reminders\" app can work properly." : "Is féidir leis an \"files_reminders\" app oibriú i gceart.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Ní mór don app \"files_reminders\" an app fógra a bheith ag obair i gceart. Ba cheart duit fógraí a chumasú nó comhaid_reminder a dhíchumasú.",
    "Set file reminders" : "Socraigh meabhrúcháin comhaid",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Meabhrúcháin comhaid**\n\nSocraigh meabhrúcháin comhaid.\n\nTabhair faoi deara: chun an aip `Meabhrúcháin Comhad` a úsáid, cinntigh go bhfuil an aip `Fógraí` suiteáilte agus cumasaithe. Soláthraíonn an aip `Fógraí` na APInna riachtanacha chun go n-oibreoidh an aip `Meabhrúcháin Comhad` i gceart.",
    "Set reminder for \"{fileName}\"" : "Socraigh meabhrúchán do \"{fileName}\"",
    "Set reminder at custom date & time" : "Socraigh meabhrúchán ar dháta agus am saincheaptha",
    "Clear reminder" : "Meabhrúchán soiléir",
    "Please choose a valid date & time" : "Roghnaigh dáta agus am bailí le do thoil",
    "Reminder set for \"{fileName}\"" : "Meabhrúchán socraithe do \"{fileName}\"",
    "Failed to set reminder" : "Theip ar an meabhrúchán a shocrú",
    "Reminder cleared for \"{fileName}\"" : "Glanadh an meabhrúchán le haghaidh \"{fileName}\"",
    "Failed to clear reminder" : "Theip ar an meabhrúchán a ghlanadh",
    "We will remind you of this file" : "Cuirfimid an comhad seo i gcuimhne duit",
    "Cancel" : "Cealaigh",
    "Set reminder" : "Socraigh meabhrúchán",
    "Reminder set" : "Meabhrúchán socraithe",
    "Set custom reminder" : "Socraigh meabhrúchán saincheaptha",
    "Later today" : "Níos déanaí inniu",
    "Set reminder for later today" : "Socraigh meabhrúchán le haghaidh níos déanaí inniu",
    "Tomorrow" : "Amárach",
    "Set reminder for tomorrow" : "Socraigh meabhrúchán don lá amárach",
    "This weekend" : "An deireadh seachtaine seo",
    "Set reminder for this weekend" : "Socraigh meabhrúchán don deireadh seachtaine seo",
    "Next week" : "An tseachtain seo chugainn",
    "Set reminder for next week" : "Socraigh meabhrúchán don tseachtain seo chugainn",
    "This files_reminder can work properly." : "Is féidir leis an gcomhad_reminder seo oibriú i gceart.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Teastaíonn an aip fógraí ón aip files_reminder chun oibriú i gceart. Ba cheart duit fógraí a chumasú nó comhaid_reminder a dhíchumasú."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-31.0.13.tar.bz2: nextcloud/apps/files_reminders/l10n/ga.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Meabhrúcháin comhaid",
    "Reminder for {name}" : "Meabhrúchán do {name}",
    "View file" : "Féach ar chomhad",
    "View folder" : "Féach ar fhillteán",
    "Files reminder" : "Meabhrúchán comhaid",
    "The \"files_reminders\" app can work properly." : "Is féidir leis an \"files_reminders\" app oibriú i gceart.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Ní mór don app \"files_reminders\" an app fógra a bheith ag obair i gceart. Ba cheart duit fógraí a chumasú nó comhaid_reminder a dhíchumasú.",
    "Set file reminders" : "Socraigh meabhrúcháin comhaid",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Meabhrúcháin comhaid**\n\nSocraigh meabhrúcháin comhaid.\n\nTabhair faoi deara: chun an aip `Meabhrúcháin Comhad` a úsáid, cinntigh go bhfuil an aip `Fógraí` suiteáilte agus cumasaithe. Soláthraíonn an aip `Fógraí` na APInna riachtanacha chun go n-oibreoidh an aip `Meabhrúcháin Comhad` i gceart.",
    "Please choose a valid date & time" : "Roghnaigh dáta agus am bailí le do thoil",
    "Reminder set for \"{fileName}\"" : "Meabhrúchán socraithe do \"{fileName}\"",
    "Failed to set reminder" : "Theip ar an meabhrúchán a shocrú",
    "Reminder cleared for \"{fileName}\"" : "Glanadh an meabhrúchán le haghaidh \"{fileName}\"",
    "Failed to clear reminder" : "Theip ar an meabhrúchán a ghlanadh",
    "Reminder at custom date & time" : "Meabhrúchán ag dáta agus am saincheaptha",
    "We will remind you of this file" : "Cuirfimid an comhad seo i gcuimhne duit",
    "Cancel" : "Cealaigh",
    "Clear reminder" : "Meabhrúchán soiléir",
    "Set reminder" : "Socraigh meabhrúchán",
    "Set reminder for " : "Socraigh meabhrúchán do",
    "Reminder set" : "Meabhrúchán socraithe",
    "Custom reminder" : "Meabhrúchán saincheaptha",
    "Later today" : "Níos déanaí inniu",
    "Set reminder for later today" : "Socraigh meabhrúchán le haghaidh níos déanaí inniu",
    "Tomorrow" : "Amárach",
    "Set reminder for tomorrow" : "Socraigh meabhrúchán don lá amárach",
    "This weekend" : "An deireadh seachtaine seo",
    "Set reminder for this weekend" : "Socraigh meabhrúchán don deireadh seachtaine seo",
    "Next week" : "An tseachtain seo chugainn",
    "Set reminder for next week" : "Socraigh meabhrúchán don tseachtain seo chugainn",
    "This files_reminder can work properly." : "Is féidir leis an gcomhad_reminder seo oibriú i gceart.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Teastaíonn an aip fógraí ón aip files_reminder chun oibriú i gceart. Ba cheart duit fógraí a chumasú nó comhaid_reminder a dhíchumasú.",
    "Set reminder for \"{fileName}\"" : "Socraigh meabhrúchán do \"{fileName}\"",
    "Set reminder at custom date & time" : "Socraigh meabhrúchán ar dháta agus am saincheaptha",
    "Set custom reminder" : "Socraigh meabhrúchán saincheaptha"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
